Documentation
¶
Index ¶
- func BgBlack(fmt any, args ...any) string
- func BgBlue(fmt any, args ...any) string
- func BgCyan(fmt any, args ...any) string
- func BgGreen(fmt any, args ...any) string
- func BgMagenta(fmt any, args ...any) string
- func BgRed(fmt any, args ...any) string
- func BgWhite(fmt any, args ...any) string
- func BgYellow(fmt any, args ...any) string
- func Black(fmt any, args ...any) string
- func Blue(fmt any, args ...any) string
- func Bold(fmt any, args ...any) string
- func Cyan(fmt any, args ...any) string
- func Dim(fmt any, args ...any) string
- func Disable()
- func Enable()
- func Green(fmt any, args ...any) string
- func Init()
- func InitUnless(disable bool)
- func Italic(fmt any, args ...any) string
- func Magenta(fmt any, args ...any) string
- func Red(fmt any, args ...any) string
- func Reverse(fmt any, args ...any) string
- func Strikethrough(fmt any, args ...any) string
- func Underline(fmt any, args ...any) string
- func White(fmt any, args ...any) string
- func Yellow(fmt any, args ...any) string
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func Init ¶
func Init()
Init initialises colours based on heuristics.
The following heuristics are used to figure out whether colour support should be disabled.
- The NO_COLOR environment variable is set.
- The terminal is not interactive.
func InitUnless ¶
func InitUnless(disable bool)
InitUnless initialises colours based on heuristics unless overridden.
Like Init, but optionally override the heuristics and force colours to be disabled if disable is set to true.
func Reverse ¶ added in v1.2.0
Reverse sets the styling to reverse (swaps foreground and background).
func Strikethrough ¶ added in v1.2.0
Strikethrough sets the styling to strikethrough.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.